/*
 * Code for class EC_EIFFEL_LAYOUT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ec650.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EC_EIFFEL_LAYOUT}.application_name */

EIF_REFERENCE F1331_13206 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (13206,RTMS_EX_H("ec",2,25955));
}

void EIF_Minit650 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
